@@ -24,14 +24,7 @@
  *
  */
 
-// use toggle buttons or uncomment check boxes
-
-//#ifndef __WXMAC__
-#define USE_TOGGLE_BUTTON 1
-//#endif
-//wxMac now has toggle buttons.
-
-#include <config.h>
+#include "hugin_config.h"
 
 #include "panoinc_WX.h"
 
@@ -94,22 +87,8 @@ BEGIN_EVENT_TABLE(PreviewFrame, wxFrame)
     EVT_CHOICE(ID_BLEND_CHOICE, PreviewFrame::OnBlendChoice)
     EVT_CHOICE(ID_PROJECTION_CHOICE, PreviewFrame::OnProjectionChoice)
     EVT_CHOICE(ID_OUTPUTMODE_CHOICE, PreviewFrame::OnOutputChoice)
-#ifdef USE_TOGGLE_BUTTON
     EVT_TOGGLEBUTTON(-1, PreviewFrame::OnChangeDisplayedImgs)
-#else
-    EVT_CHECKBOX(-1, PreviewFrame::OnChangeDisplayedImgs)
-#endif
-#ifndef __WXMAC__
 	EVT_SCROLL_CHANGED(PreviewFrame::OnChangeFOV)
-#else
- #if wxCHECK_VERSION(2,9,0)
-	EVT_SCROLL_CHANGED(PreviewFrame::OnChangeFOV)
- #else
-	EVT_SCROLL_THUMBRELEASE(PreviewFrame::OnChangeFOV)
-	EVT_SCROLL_ENDSCROLL(PreviewFrame::OnChangeFOV)
-	EVT_SCROLL_THUMBTRACK(PreviewFrame::OnChangeFOV)
- #endif
-#endif
 	EVT_TOOL(ID_FULL_SCREEN, PreviewFrame::OnFullScreen)
     EVT_TOOL(ID_UNDO, PreviewFrame::OnUndo)
     EVT_TOOL(ID_REDO, PreviewFrame::OnRedo)
@@ -174,11 +153,7 @@ PreviewFrame::PreviewFrame(wxFrame * frame, HuginBase::Panorama &pano)
                                 _("VFOV"));
     m_VFOVSlider->SetLineSize(2);
     m_VFOVSlider->SetPageSize(10);
-#if wxCHECK_VERSION(3,0,0)
     m_VFOVSlider->SetTickFreq(5);
-#else
-    m_VFOVSlider->SetTickFreq(5,0);
-#endif
     m_VFOVSlider->SetToolTip(_("drag to change the vertical field of view"));
 
     flexSizer->Add(m_VFOVSlider, 0, wxEXPAND);
@@ -191,11 +166,7 @@ PreviewFrame::PreviewFrame(wxFrame * frame, HuginBase::Panorama &pano)
                                 _("HFOV"));
     m_HFOVSlider->SetPageSize(10);
     m_HFOVSlider->SetLineSize(2);
-#if wxCHECK_VERSION(3,0,0)
     m_HFOVSlider->SetTickFreq(5);
-#else
-    m_HFOVSlider->SetTickFreq(5,0);
-#endif
 
     m_HFOVSlider->SetToolTip(_("drag to change the horizontal field of view"));
 
@@ -407,7 +378,6 @@ PreviewFrame::~PreviewFrame()
 {
     DEBUG_TRACE("dtor writing config");
     wxConfigBase * config = wxConfigBase::Get();
-    wxSize sz = GetClientSize();
 
     StoreFramePosition(this, wxT("PreviewFrame"));
 
@@ -559,17 +529,11 @@ void PreviewFrame::panoramaImagesChanged(HuginBase::Panorama &pano, const HuginB
             if (*it >= nrButtons) {
                 // create new item.
 //                wxImage * bmp = new wxImage(sz.GetWidth(), sz.GetHeight());
-#ifdef USE_TOGGLE_BUTTON
                 wxToggleButton * but = new wxToggleButton(m_ButtonPanel,
                                                           ID_TOGGLE_BUT + *it,
                                                           wxString::Format(wxT("%d"),*it),
                                                           wxDefaultPosition, wxDefaultSize,
                                                           wxBU_EXACTFIT);
-#else
-                wxCheckBox * but = new wxCheckBox(m_ButtonPanel,
-                                                  ID_TOGGLE_BUT + *it,
-                                                  wxString::Format(wxT("%d"),*it));
-#endif
                 wxSize sz = but->GetSize();
 //                but->SetSize(res.GetWidth(),sz.GetHeight());
                 // HACK.. set fixed width. that should work
@@ -596,11 +560,7 @@ void PreviewFrame::panoramaImagesChanged(HuginBase::Panorama &pano, const HuginB
     }
 
     if (dirty) {
-#if wxCHECK_VERSION(3,0,0)
         m_ButtonSizer->FitInside(m_ButtonPanel);
-#else
-		m_ButtonSizer->SetVirtualSizeHints(m_ButtonPanel);
-#endif
 		// Layout();
 		DEBUG_INFO("New m_ButtonPanel width: " << (m_ButtonPanel->GetSize()).GetWidth());
 		DEBUG_INFO("New m_ButtonPanel Height: " << (m_ButtonPanel->GetSize()).GetHeight());
